==> calligra-2.4.3.tar.xz: calligra-2.4.3/plugins/textshape/dialogs/ParagraphSettingsDialog.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007, 2010 Thomas Zander <zander@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ParagraphSettingsDialog.h"

#include "ParagraphGeneral.h"
#include "../TextTool.h"

#include <KoParagraphStyle.h>
#include <KoTextDocument.h>
#include <KoTextEditor.h>
#include <KoListLevelProperties.h>

#include <QTextBlock>
#include <QTimer>

ParagraphSettingsDialog::ParagraphSettingsDialog(TextTool *tool, KoTextEditor *editor, QWidget* parent)
        : KDialog(parent),
        m_tool(tool),
        m_editor(editor)
{
    setCaption(i18n("Paragraph Format"));
    setModal(true);
    setButtons(Ok | Cancel | Apply);
    setDefaultButton(Ok);

    m_paragraphGeneral = new ParagraphGeneral;
    m_paragraphGeneral->hideStyleName(true);
    setMainWidget(m_paragraphGeneral);

    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
    connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
    initTabs();
}

ParagraphSettingsDialog::~ParagraphSettingsDialog()
{
}

void ParagraphSettingsDialog::initTabs()
{
    KoParagraphStyle *style = KoParagraphStyle::fromBlock(m_editor->block());
    m_paragraphGeneral->setStyle(style, KoList::level(m_editor->block()));
}

void ParagraphSettingsDialog::slotOk()
{
    slotApply();
    KDialog::accept();
}

void ParagraphSettingsDialog::slotApply()
{
    m_editor->beginEditBlock(i18n("Paragraph Settings"));
    KoParagraphStyle chosenStyle;
    m_paragraphGeneral->save(&chosenStyle);
    QTextCharFormat cformat;
    QTextBlockFormat format;
    chosenStyle.KoCharacterStyle::applyStyle(cformat);
    chosenStyle.applyStyle(format);

    m_editor->mergeAutoStyle(cformat, format);
    if (chosenStyle.listStyle()) {
        KoTextEditor::ChangeListFlags flags(KoTextEditor::AutoListStyle | KoTextEditor::DontUnsetIfSame);
        m_tool->textEditor()->setListProperties(chosenStyle.listStyle()->levelProperties(chosenStyle.listStyle()->listLevels().first()),
                                                flags);
    } else {
        QTextList *list = m_editor->block().textList();
        if (list) { // then remove it.
            list->remove(m_editor->block());
        }
    }
    m_editor->endEditBlock();
}

void ParagraphSettingsDialog::setUnit(const KoUnit &unit)
{
    m_paragraphGeneral->setUnit(unit);
}

#include <ParagraphSettingsDialog.moc>

==> calligra_2.7.2.orig.tar.xz: calligra-2.7.2/plugins/textshape/dialogs/ParagraphSettingsDialog.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007, 2010 Thomas Zander <zander@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ParagraphSettingsDialog.h"

#include "ParagraphGeneral.h"
#include "../TextTool.h"

#include <KoParagraphStyle.h>
#include <KoTextDocument.h>
#include <KoTextEditor.h>
#include <KoListLevelProperties.h>
#include <commands/ParagraphFormattingCommand.h>

#include <QTextBlock>
#include <QTimer>

ParagraphSettingsDialog::ParagraphSettingsDialog(TextTool *tool, KoTextEditor *editor, QWidget* parent)
        : KDialog(parent)
        , m_tool(tool)
        , m_editor(editor)
        , m_styleChanged(false)
{
    setCaption(i18n("Paragraph Format"));
    setModal(true);
    setButtons(Ok | Cancel | Apply);
    setDefaultButton(Ok);

    m_paragraphGeneral = new ParagraphGeneral;
    m_paragraphGeneral->hideStyleName(true);
    setMainWidget(m_paragraphGeneral);


    connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
    connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
    initTabs();

    // Do this after initTabs so it doesn't cause signals prematurely
    connect(m_paragraphGeneral, SIGNAL(styleChanged()), this, SLOT(styleChanged()));
}

ParagraphSettingsDialog::~ParagraphSettingsDialog()
{
}

void ParagraphSettingsDialog::initTabs()
{
    KoParagraphStyle *style = KoParagraphStyle::fromBlock(m_editor->block());
    m_paragraphGeneral->setStyle(style, KoList::level(m_editor->block()));
}

void ParagraphSettingsDialog::styleChanged(bool state)
{
    m_styleChanged = state;
}

void ParagraphSettingsDialog::slotOk()
{
    slotApply();
    KDialog::accept();
}

void ParagraphSettingsDialog::slotApply()
{
    if (!m_styleChanged)
        return;

    KoParagraphStyle chosenStyle;
    m_paragraphGeneral->save(&chosenStyle);

    QTextCharFormat cformat;
    QTextBlockFormat format;
    chosenStyle.KoCharacterStyle::applyStyle(cformat);
    chosenStyle.applyStyle(format);

    KoListLevelProperties llp;
    if (chosenStyle.listStyle()) {
        llp = chosenStyle.listStyle()->levelProperties(chosenStyle.listStyle()->listLevels().first());
    } else {
        llp.setStyle(KoListStyle::None);
    }

    m_editor->applyDirectFormatting(cformat, format, llp);

    m_styleChanged = false;
}

void ParagraphSettingsDialog::setUnit(const KoUnit &unit)
{
    m_paragraphGeneral->setUnit(unit);
}

void ParagraphSettingsDialog::setImageCollection(KoImageCollection *imageCollection)
{
    m_paragraphGeneral->setImageCollection(imageCollection);
}

#include <ParagraphSettingsDialog.moc>
